from alembic import command
import json
import secrets
import click


@click.command()
@click.argument("samples_dir")
@click.option("--redis_connection", help="Redis connection string (for celery). Defaults to \"redis://127.0.0.1:6379\"")
@click.option('--secret', help="Secret key to use. A random hex string will be generated if not provided")
@click.option('--db', 'connection', help="Database connection string. Defaults to \"sqlite:///test.db\"")
def main(samples_dir, redis_connection=None, secret=None, connection=None):
    config = {
        "SAMPLE_DIR": samples_dir,
        "SECRET_KEY": secret or secrets.token_hex(),
        "SQLALCHEMY_DATABASE_URI": connection or 'sqlite:///test.db',
        "CELERY_RESULT_BACKEND": redis_connection or 'redis://127.0.0.1:6379',
        "CELERY_BROKER_URL": redis_connection or 'redis://127.0.0.1:6379'
    }
    with open('config.json', 'w') as f:
        json.dump(config, f, indent=2)

    # HACK: this is probably not the best way to make sure the built config is applied before we do anything else
    from main import app, db, migrate

    db.create_all()

    config = migrate.get_config()
    with app.app_context():
        command.stamp(config, 'head', sql=False, tag=None)


if __name__ == '__main__':
    main()
